summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--lib/private/BackgroundJob/JobList.php3
1 files changed, 2 insertions, 1 deletions
diff --git a/lib/private/BackgroundJob/JobList.php b/lib/private/BackgroundJob/JobList.php
index fbeee1f56e9..3cdfee51138 100644
--- a/lib/private/BackgroundJob/JobList.php
+++ b/lib/private/BackgroundJob/JobList.php
@@ -307,7 +307,8 @@ class JobList implements IJobList {
$class = $row['class'];
$job = new $class();
} else {
- // job from disabled app or old version of an app, no need to do anything
+ // Remove job from disabled app or old version of an app
+ $this->removeById($row['id']);
return null;
}
}